@@ -9,26 +9,12 @@
  * Program and source code released under the GPL version 2
  *
  */
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
-#include "is_ws.h"
-#include "intlist.h"
+
 #include "str.h"
-#include "utf8.h"
-#include "str_conv.h"
 #include "fields.h"
 #include "slist.h"
 #include "name.h"
-#include "title.h"
-#include "url.h"
-#include "reftypes.h"
 #include "latex_parse.h"
-#include "bibformats.h"
-#include "generic.h"
-
-#include "R.h"
 
 #include "common_bt_btd_blt.h"
 
@@ -132,7 +118,7 @@ bibtex_cleanvalue( str *value )
 	str parsed;
 
 	str_init( &parsed );
-// REprintf("before clean: %s\n", value->data);
+	// REprintf("bibtex_cleanvalue: before clean: %s\n", value->data);
 
 	status = latex_parse( value, &parsed );
 	if ( status!=BIBL_OK ) goto out;
@@ -295,7 +281,7 @@ bibtexin_person( fields *bibin, int m, param *pm )
 {
 	int status, match = 0;
 	slist tokens;
-	// REprintf("\nbibtexdirectin_person!\n");
+	// REprintf("\nbibtexin_person!\n");
 
 	status = bibtex_matches_asis_or_corps( bibin, m, pm, &match );
 	if ( status!=BIBL_OK || match==1 ) return status;
