@@ -4,7 +4,7 @@
  * Version: 2018-09-21
  *
  * Copyright (c) Chris Putnam 1999-2020
- * Copyright (c) Georgi N. Boshnakov 2020
+ * Copyright (c) Georgi N. Boshnakov 2020-2021
  *
  * Source code released under the GPL version 2
  *
@@ -214,13 +214,47 @@ str_mergestrs( str *s, ... )
 static void 
 str_initalloc( str *s, unsigned long minsize )
 {
-	unsigned long size = str_initlen;
-	assert( s );
-	if ( minsize > str_initlen ) size = minsize;
-	s->data = (char *) malloc( sizeof( *(s->data) ) * size );
-	if ( !s->data ) {
-		REprintf("Error.  Cannot allocate memory in str_initalloc, requested %lu characters.\n", size );
-		error("\n"); // error( EXIT_FAILURE );
+       unsigned long size = str_initlen;
+       assert( s );
+       if ( minsize > str_initlen ) size = minsize;
+       s->data = (char *) malloc( sizeof( *(s->data) ) * size );
+       //     tried changing to calloc() to avoid this kind of error from valgrind:
+        //      > bibConvert(fn_med, bib, informat = "med")
+        //      ==16041== Conditional jump or move depends on uninitialised value(s)
+        //      ==16041==    at 0x10CCF2A3: xml_processtag (xml.c:174)
+        //      ==16041==    by 0x10CCF69E: xml_parse (xml.c:241)
+        //      ==16041==    by 0x10CD1838: xml_getencoding (xml_encoding.c:72)
+        //      ==16041==    by 0x10CB120F: medin_readf (medin.c:103)
+        //      ==16041==    by 0x10C8ACF2: read_refs (bibcore.c:471)
+        //      ==16041==    by 0x10C8BE0E: bibl_read (bibcore.c:862)
+        //      ==16041==    by 0x10C98B64: bibprog (bibprog.c:36)
+        //      ==16041==    by 0x10C889EC: any2xml_main (any2xml.c:127)
+        //      ==16041==    by 0x494E7AD: do_dotCode (dotcode.c:1811)
+        //      ==16041==    by 0x499F92F: bcEval (eval.c:7115)
+        //      ==16041==    by 0x498B056: Rf_eval (eval.c:727)
+        //      ==16041==    by 0x498DDC5: R_execClosure (eval.c:1897)
+        //      ==16041==  Uninitialised value was created by a heap allocation
+        //      ==16041==    at 0x483B7F3: malloc (in /usr/lib/x86_64-linux-gnu/valgrind/vgpreload_memcheck-amd64-linux.so)
+        //      ==16041==    by 0x10CC6770: str_initalloc (str.c:226)
+        //      ==16041==    by 0x10CC721F: str_strcpy_ensurespace (str.c:513)
+        //      ==16041==    by 0x10CC7277: str_strcpy_internal (str.c:523)
+        //      ==16041==    by 0x10CC73BF: str_segcpy (str.c:579)
+        //      ==16041==    by 0x10CD1805: xml_getencoding (xml_encoding.c:70)
+        //      ==16041==    by 0x10CB120F: medin_readf (medin.c:103)
+        //      ==16041==    by 0x10C8ACF2: read_refs (bibcore.c:471)
+        //      ==16041==    by 0x10C8BE0E: bibl_read (bibcore.c:862)
+        //      ==16041==    by 0x10C98B64: bibprog (bibprog.c:36)
+        //      ==16041==    by 0x10C889EC: any2xml_main (any2xml.c:127)
+        //      ==16041==    by 0x494E7AD: do_dotCode (dotcode.c:1811)
+       //
+       // TODO:
+       //    The data is not really left uninitialised and there may be a better way to let the compiler know.
+        // WWD: fixing str_strcpy_internal takes care of memory misuse.
+       //
+       // s->data = (char *) calloc( size, sizeof( *(s->data) ) );
+       if ( !s->data ) {
+         error("Error.  Cannot allocate memory in str_initalloc, requested %lu characters.\n\n", size );
+         // error("\n"); // error( EXIT_FAILURE );
 	}
 	s->data[0]='\0';
 	s->dim=size;
@@ -516,15 +550,50 @@ str_strcpy_internal( str *s, const char *p, unsigned long n )
 	return_if_memerr( s );
 
 	str_strcpy_ensurespace( s, n );
-	// Georgi: this fixes the warning about truncation in strncpy
-	//   strcpy cannot be used here since at least one of the calls below
-	//   passes a non-NULL terminated 'p'
-	strncpy( s->data, p, n + 1);
-	// strncpy( s->data, p, n );
-	// s->data[n] = '\0';
-	s->len = n;
-}
+        // Georgi: (Github commit 20efd6 on 4 Jul 2020)
+        //
+        // This fixes the warning about truncation in strncpy
+        // strcpy cannot be used here since at least one of the calls below
+        // passes a non-NULL terminated 'p'
+        //
+        // strncpy( s->data, p, n + 1); // WWD: ???
+        //
+        // n + 1 above since strncpy( s->data, p, n ); triggers a compiler complaint on
+        // Windows (R devel, release, oldrel; but not on R 3.3):
+        //   str.c:557:8: warning: 'strncpy' output truncated before terminating nul
+        //	         copying as many bytes from a string as its length
+        //                [-Wstringop-truncation]
+        // Don't know why the warning is on Windows only, especially as the compiler
+        // doesn't complain about assigning to s->data[n] but copying n + 1 bytes seems
+        // harmless (the last byte would be either null or the next byte in the source
+        // string, in both cases immediately overwitten). I see two possible problems
+        // with this:
+        //     1) in principle, p may be pointing to a non-null terminated chunk
+        //        of memory, in which case the chunk may not have n+1 byte allocated
+        //        (which would explain the 1 byte unallocated memory  error in v2.2.2).
+        //     2) p[n-1] may be 0, the terminating byte of the string. This is clearly
+        //        not the intention (assignments s->data[n] = '\0'; s->len = n;) but 
+        //        may be due to upstream error(s). In this case there is no guarantee
+        //        that the (n+1)th byte is allocated and/or initialised.
+        //
+        // Both can explain the 1 byte unallocated memory error in v2.2.2.
 
+       	// (Github commit 108b531) Switching to memcpy() to fix the warning about
+       	// truncation in strncpy.
+       	//
+       	// memcpy() is not completely equivalent to strncpy(), since the latter
+       	// handles the case when p points to a shorter string. But as far as I can
+       	// see, the callers of str_strcpy_internal really require n bytes to be
+       	// copied and the assignment below s->len = n; assumes that the copied string
+       	// does not contain null bytes.
+       	//
+       	// strncpy( s->data, p, n);
+	memcpy( s->data, p, n);
+	s->data[n] = '\0';
+	s->len = n;
+	// if(strlen(s->data) != n)
+	//     error("\n\tinconsistency!\n");
+}
 void
 str_strcpy( str *s, str *from )
 {
